==> haskell-graphviz-2999.19.0.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-graphviz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: graphviz
version: 2999.19.0.0
id: graphviz-2999.19.0.0-3HlW4xfjF4R3xvYngymrYQ
key: graphviz-2999.19.0.0-3HlW4xfjF4R3xvYngymrYQ
license: BSD3
copyright: Matthew Sackman, Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
stability: Beta
homepage: http://projects.haskell.org/graphviz/
synopsis: Bindings to Graphviz for graph visualisation.
description:
    This library provides bindings for the Dot language used by the
    Graphviz (<http://graphviz.org/>) suite of programs for visualising
    graphs, as well as functions to call those programs.
    .
    Main features of the graphviz library include:
    .
    * Almost complete coverage of all Graphviz attributes and syntax.
    .
    * Support for specifying clusters.
    .
    * The ability to use a custom node type.
    .
    * Functions for running a Graphviz layout tool with all specified
    output types.
    .
    * The ability to not only generate but also parse Dot code with two
    options: strict and liberal (in terms of ordering of statements).
    .
    * Functions to convert FGL graphs and other graph-like data structures
    to Dot code - including support to group them into clusters - with a
    high degree of customisation by specifying which attributes to use
    and limited support for the inverse operation.
    .
    * Round-trip support for passing an FGL graph through Graphviz to
    augment node and edge labels with positional information, etc.
category: Graphs, Graphics
author: Matthew Sackman, Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Data.GraphViz Data.GraphViz.Algorithms Data.GraphViz.Attributes
    Data.GraphViz.Attributes.Colors
    Data.GraphViz.Attributes.Colors.Brewer
    Data.GraphViz.Attributes.Colors.SVG
    Data.GraphViz.Attributes.Colors.X11
    Data.GraphViz.Attributes.Complete Data.GraphViz.Attributes.HTML
    Data.GraphViz.Attributes.Internal Data.GraphViz.Commands
    Data.GraphViz.Commands.IO Data.GraphViz.Exception
    Data.GraphViz.Internal.State Data.GraphViz.Internal.Util
    Data.GraphViz.Parsing Data.GraphViz.PreProcessing
    Data.GraphViz.Printing Data.GraphViz.Types
    Data.GraphViz.Types.Canonical Data.GraphViz.Types.Generalised
    Data.GraphViz.Types.Graph Data.GraphViz.Types.Internal.Common
    Data.GraphViz.Types.Monadic
hidden-modules: Data.GraphViz.Algorithms.Clustering
                Data.GraphViz.Attributes.Arrows
                Data.GraphViz.Attributes.ColorScheme Data.GraphViz.Attributes.Same
                Data.GraphViz.Attributes.Values Data.GraphViz.Commands.Available
                Data.GraphViz.Types.State
abi: 6f823d2f8bb4ddc864d3529f2eae0431
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/graphviz-2999.19.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/graphviz-2999.19.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/graphviz-2999.19.0.0
hs-libraries: HSgraphviz-2999.19.0.0-3HlW4xfjF4R3xvYngymrYQ
depends:
    base-4.10.1.0 containers-0.5.10.2 process-1.6.1.0 directory-1.3.0.2
    temporary-1.2.1.1-7a1ypWDsHB4EWhBxWwtUro
    fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM filepath-1.4.1.2
    polyparse-1.12-AFzL2h9QDVDHxoHvzT5Sbw bytestring-0.10.8.2
    colour-2.3.4-4FOR755TjbXCteGD5Oe26Q transformers-0.5.2.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
    dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             temporary-1.2.1.1-7a1ypWDsHB4EWhBxWwtUro=2f783cb69e36d36009911feb4a65936c
             fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM=8107c7ec0408e8805abfc786bf663252
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             polyparse-1.12-AFzL2h9QDVDHxoHvzT5Sbw=3edcf247afd857cc05db1db934ac17c6
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             colour-2.3.4-4FOR755TjbXCteGD5Oe26Q=a7ebaafac3cafd906ad8ea8e0147bdb8
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ=85a5810eee98c47d6201832708734120
             dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ=b107514e173207d2f3e9b5aba950dc0f
haddock-interfaces: /usr/share/doc/haskell-graphviz/html/graphviz.haddock
haddock-html: /usr/share/doc/haskell-graphviz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphviz-2999.19.0.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-graphviz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: graphviz
version: 2999.19.0.0
id: graphviz-2999.19.0.0-4hGdA1Z0qkC9ahI2FroxzD
key: graphviz-2999.19.0.0-4hGdA1Z0qkC9ahI2FroxzD
license: BSD3
copyright: Matthew Sackman, Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
stability: Beta
homepage: http://projects.haskell.org/graphviz/
synopsis: Bindings to Graphviz for graph visualisation.
description:
    This library provides bindings for the Dot language used by the
    Graphviz (<http://graphviz.org/>) suite of programs for visualising
    graphs, as well as functions to call those programs.
    .
    Main features of the graphviz library include:
    .
    * Almost complete coverage of all Graphviz attributes and syntax.
    .
    * Support for specifying clusters.
    .
    * The ability to use a custom node type.
    .
    * Functions for running a Graphviz layout tool with all specified
    output types.
    .
    * The ability to not only generate but also parse Dot code with two
    options: strict and liberal (in terms of ordering of statements).
    .
    * Functions to convert FGL graphs and other graph-like data structures
    to Dot code - including support to group them into clusters - with a
    high degree of customisation by specifying which attributes to use
    and limited support for the inverse operation.
    .
    * Round-trip support for passing an FGL graph through Graphviz to
    augment node and edge labels with positional information, etc.
category: Graphs, Graphics
author: Matthew Sackman, Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Data.GraphViz Data.GraphViz.Algorithms Data.GraphViz.Attributes
    Data.GraphViz.Attributes.Colors
    Data.GraphViz.Attributes.Colors.Brewer
    Data.GraphViz.Attributes.Colors.SVG
    Data.GraphViz.Attributes.Colors.X11
    Data.GraphViz.Attributes.Complete Data.GraphViz.Attributes.HTML
    Data.GraphViz.Attributes.Internal Data.GraphViz.Commands
    Data.GraphViz.Commands.IO Data.GraphViz.Exception
    Data.GraphViz.Internal.State Data.GraphViz.Internal.Util
    Data.GraphViz.Parsing Data.GraphViz.PreProcessing
    Data.GraphViz.Printing Data.GraphViz.Types
    Data.GraphViz.Types.Canonical Data.GraphViz.Types.Generalised
    Data.GraphViz.Types.Graph Data.GraphViz.Types.Internal.Common
    Data.GraphViz.Types.Monadic
hidden-modules: Data.GraphViz.Algorithms.Clustering
                Data.GraphViz.Attributes.Arrows
                Data.GraphViz.Attributes.ColorScheme Data.GraphViz.Attributes.Same
                Data.GraphViz.Attributes.Values Data.GraphViz.Commands.Available
                Data.GraphViz.Types.State
abi: ff65395c8a177a8469dfba0071e16ba5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/graphviz-2999.19.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/graphviz-2999.19.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/graphviz-2999.19.0.0
hs-libraries: HSgraphviz-2999.19.0.0-4hGdA1Z0qkC9ahI2FroxzD
depends:
    base-4.10.1.0 containers-0.5.10.2 process-1.6.1.0 directory-1.3.0.2
    temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2
    fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM filepath-1.4.1.2
    polyparse-1.12-8M9M90ciq4cmr3MBHxcds bytestring-0.10.8.2
    colour-2.3.4-Ga6yBh95iV34FXzxXxoROF transformers-0.5.2.0
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    wl-pprint-text-1.1.1.0-1EN8qG3vtYQKnmkd2k9Ew2
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2=b86cfc09a1f585d90dca5d21791f6633
             fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM=8107c7ec0408e8805abfc786bf663252
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             polyparse-1.12-8M9M90ciq4cmr3MBHxcds=92f7180df5bbe8503ba6bd254254136f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             colour-2.3.4-Ga6yBh95iV34FXzxXxoROF=f36a892291922aff6a465f9184182662
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             wl-pprint-text-1.1.1.0-1EN8qG3vtYQKnmkd2k9Ew2=c0e784fe4a1bed5d73b66e3be1734ae4
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=b98e175ed6b9bea3c0e69ce59165f686
haddock-interfaces: /usr/share/doc/haskell-graphviz/html/graphviz.haddock
haddock-html: /usr/share/doc/haskell-graphviz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
